# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import account
from . import account_move
from . import product
from . import project
from . import project_update
from . import sale_order
from . import res_config_settings
from . import project_sale_line_employee_map
